@@ -8,6 +8,7 @@ import pathlib
 
 class Jezdzenka:
     def __init__(self):
+        self.archived_directory = "/archive"
         self.configuration = self.config()
         self.connection = self.database()
         self.table = self.connection.table('objects')
@@ -24,6 +25,8 @@ class Jezdzenka:
         if directory is not None:
             if not os.path.exists(directory):
                 os.makedirs(directory)
+            if not os.path.exists(directory + self.archived_directory):
+                os.makedirs(directory + self.archived_directory)
         return directory
 
     def database(self):
