@@ -3,7 +3,7 @@ from datetime import datetime
 from jezdzenka.classes.Pkpass import Pkpass, Special
 from jezdzenka.console.forms import new_empty_prompt, type_prompt
 from jezdzenka.database import collection
-from jezdzenka.database.manipulation import add_new_from_form, update_object
+from jezdzenka.database.manipulation import add_new_from_form, update_object, move_file, move_file_to_app
 
 
 def create(args):
