@@ -10,6 +10,7 @@ from jezdzenka.application import app as jezdzenka
 
 def move_file(file, additional_directory, new_name):
     directory = jezdzenka.configuration + additional_directory
+    print(os.path.join(directory, new_name))
     os.rename(file, os.path.join(directory, new_name))
 
 
@@ -18,7 +19,7 @@ def move_file_to_app(information, file):
     new_name = information['relevant_date'].strftime("%Y%m%d%H%M%S") \
         + re.sub('[\W_]+', '', information['organization']) + '#' \
         + re.sub('[\W_]+', '', information['id']) + extension
-    move_file(file, new_name, "")
+    move_file(file, "", new_name)
     return new_name
 
 
